# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import logging as std_logging
import re
from typing import (
    Callable,
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry_async as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.servicehealth_v1 import gapic_version as package_version

try:
    OptionalRetry = Union[retries.AsyncRetry, gapic_v1.method._MethodDefault, None]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.AsyncRetry, object, None]  # type: ignore

from google.cloud.location import locations_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore

from google.cloud.servicehealth_v1.services.service_health import pagers
from google.cloud.servicehealth_v1.types import event_resources

from .client import ServiceHealthClient
from .transports.base import DEFAULT_CLIENT_INFO, ServiceHealthTransport
from .transports.grpc_asyncio import ServiceHealthGrpcAsyncIOTransport

try:
    from google.api_core import client_logging  # type: ignore

    CLIENT_LOGGING_SUPPORTED = True  # pragma: NO COVER
except ImportError:  # pragma: NO COVER
    CLIENT_LOGGING_SUPPORTED = False

_LOGGER = std_logging.getLogger(__name__)


class ServiceHealthAsyncClient:
    """Request service health events relevant to your Google Cloud
    project.
    """

    _client: ServiceHealthClient

    # Copy defaults from the synchronous client for use here.
    # Note: DEFAULT_ENDPOINT is deprecated. Use _DEFAULT_ENDPOINT_TEMPLATE instead.
    DEFAULT_ENDPOINT = ServiceHealthClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = ServiceHealthClient.DEFAULT_MTLS_ENDPOINT
    _DEFAULT_ENDPOINT_TEMPLATE = ServiceHealthClient._DEFAULT_ENDPOINT_TEMPLATE
    _DEFAULT_UNIVERSE = ServiceHealthClient._DEFAULT_UNIVERSE

    event_path = staticmethod(ServiceHealthClient.event_path)
    parse_event_path = staticmethod(ServiceHealthClient.parse_event_path)
    organization_event_path = staticmethod(ServiceHealthClient.organization_event_path)
    parse_organization_event_path = staticmethod(
        ServiceHealthClient.parse_organization_event_path
    )
    organization_impact_path = staticmethod(
        ServiceHealthClient.organization_impact_path
    )
    parse_organization_impact_path = staticmethod(
        ServiceHealthClient.parse_organization_impact_path
    )
    common_billing_account_path = staticmethod(
        ServiceHealthClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        ServiceHealthClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(ServiceHealthClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        ServiceHealthClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        ServiceHealthClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        ServiceHealthClient.parse_common_organization_path
    )
    common_project_path = staticmethod(ServiceHealthClient.common_project_path)
    parse_common_project_path = staticmethod(
        ServiceHealthClient.parse_common_project_path
    )
    common_location_path = staticmethod(ServiceHealthClient.common_location_path)
    parse_common_location_path = staticmethod(
        ServiceHealthClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            ServiceHealthAsyncClient: The constructed client.
        """
        return ServiceHealthClient.from_service_account_info.__func__(ServiceHealthAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            ServiceHealthAsyncClient: The constructed client.
        """
        return ServiceHealthClient.from_service_account_file.__func__(ServiceHealthAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return ServiceHealthClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> ServiceHealthTransport:
        """Returns the transport used by the client instance.

        Returns:
            ServiceHealthTransport: The transport used by the client instance.
        """
        return self._client.transport

    @property
    def api_endpoint(self):
        """Return the API endpoint used by the client instance.

        Returns:
            str: The API endpoint used by the client instance.
        """
        return self._client._api_endpoint

    @property
    def universe_domain(self) -> str:
        """Return the universe domain used by the client instance.

        Returns:
            str: The universe domain used
                by the client instance.
        """
        return self._client._universe_domain

    get_transport_class = ServiceHealthClient.get_transport_class

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Optional[
            Union[str, ServiceHealthTransport, Callable[..., ServiceHealthTransport]]
        ] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the service health async client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Optional[Union[str,ServiceHealthTransport,Callable[..., ServiceHealthTransport]]]):
                The transport to use, or a Callable that constructs and returns a new transport to use.
                If a Callable is given, it will be called with the same set of initialization
                arguments as used in the ServiceHealthTransport constructor.
                If set to None, a transport is chosen automatically.
            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]):
                Custom options for the client.

                1. The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client when ``transport`` is
                not explicitly provided. Only if this property is not set and
                ``transport`` was not explicitly provided, the endpoint is
                determined by the GOOGLE_API_USE_MTLS_ENDPOINT environment
                variable, which have one of the following values:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto-switch to the
                default mTLS endpoint if client certificate is present; this is
                the default value).

                2. If the GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide a client certificate for mTLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

                3. The ``universe_domain`` property can be used to override the
                default "googleapis.com" universe. Note that ``api_endpoint``
                property still takes precedence; and ``universe_domain`` is
                currently not supported for mTLS.

            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = ServiceHealthClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

        if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
            std_logging.DEBUG
        ):  # pragma: NO COVER
            _LOGGER.debug(
                "Created client `google.cloud.servicehealth_v1.ServiceHealthAsyncClient`.",
                extra={
                    "serviceName": "google.cloud.servicehealth.v1.ServiceHealth",
                    "universeDomain": getattr(
                        self._client._transport._credentials, "universe_domain", ""
                    ),
                    "credentialsType": f"{type(self._client._transport._credentials).__module__}.{type(self._client._transport._credentials).__qualname__}",
                    "credentialsInfo": getattr(
                        self.transport._credentials, "get_cred_info", lambda: None
                    )(),
                }
                if hasattr(self._client._transport, "_credentials")
                else {
                    "serviceName": "google.cloud.servicehealth.v1.ServiceHealth",
                    "credentialsType": None,
                },
            )

    async def list_events(
        self,
        request: Optional[Union[event_resources.ListEventsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> pagers.ListEventsAsyncPager:
        r"""Lists events under a given project and location.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_list_events():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.ListEventsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_events(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.ListEventsRequest, dict]]):
                The request object. Requests list of events.
            parent (:class:`str`):
                Required. Parent value using the form
                ``projects/{project_id}/locations/{location}/events``.

                ``project_id`` - ID of the project for which to list
                service health events. ``location`` - The location to
                get the service health events from. To retrieve service
                health events of category = INCIDENT, use ``location`` =
                ``global``.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.services.service_health.pagers.ListEventsAsyncPager:
                Response to request for listing
                events.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.ListEventsRequest):
            request = event_resources.ListEventsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.list_events
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListEventsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_event(
        self,
        request: Optional[Union[event_resources.GetEventRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> event_resources.Event:
        r"""Retrieves a resource containing information about an
        event.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_get_event():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.GetEventRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_event(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.GetEventRequest, dict]]):
                The request object. Gets information about a specific
                event.
            name (:class:`str`):
                Required. Unique name of the event in this scope
                including project and location using the form
                ``projects/{project_id}/locations/{location}/events/{event_id}``.

                ``project_id`` - Project ID of the project that contains
                the event. ``location`` - The location to get the
                service health events from. ``event_id`` - Event ID to
                retrieve.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.types.Event:
                Represents service health events that
                may affect Google Cloud products. Event
                resource is a read-only view and does
                not allow any modifications. All fields
                are output only.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.GetEventRequest):
            request = event_resources.GetEventRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.get_event
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_organization_events(
        self,
        request: Optional[
            Union[event_resources.ListOrganizationEventsRequest, dict]
        ] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> pagers.ListOrganizationEventsAsyncPager:
        r"""Lists organization events under a given organization
        and location.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_list_organization_events():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.ListOrganizationEventsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_organization_events(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.ListOrganizationEventsRequest, dict]]):
                The request object. Requests list of events that affect
                an organization.
            parent (:class:`str`):
                Required. Parent value using the form
                ``organizations/{organization_id}/locations/{location}/organizationEvents``.

                ``organization_id`` - ID (number) of the project that
                contains the event. To get your ``organization_id``, see
                `Getting your organization resource
                ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
                ``location`` - The location to get the service health
                events from. To retrieve service health events of
                category = INCIDENT, use ``location`` = ``global``.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.services.service_health.pagers.ListOrganizationEventsAsyncPager:
                Response to request for listing
                organization events.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.ListOrganizationEventsRequest):
            request = event_resources.ListOrganizationEventsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.list_organization_events
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListOrganizationEventsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_organization_event(
        self,
        request: Optional[
            Union[event_resources.GetOrganizationEventRequest, dict]
        ] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> event_resources.OrganizationEvent:
        r"""Retrieves a resource containing information about an
        event affecting an organization .

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_get_organization_event():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.GetOrganizationEventRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_organization_event(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.GetOrganizationEventRequest, dict]]):
                The request object. Gets information about a specific
                event affecting an organization.
            name (:class:`str`):
                Required. Unique name of the event in this scope
                including organization and event ID using the form
                ``organizations/{organization_id}/locations/locations/global/organizationEvents/{event_id}``.

                ``organization_id`` - ID (number) of the project that
                contains the event. To get your ``organization_id``, see
                `Getting your organization resource
                ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
                ``event_id`` - Organization event ID to retrieve.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.types.OrganizationEvent:
                Represents service health events that
                may affect Google Cloud products used
                across the organization. It is a
                read-only view and does not allow any
                modifications.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.GetOrganizationEventRequest):
            request = event_resources.GetOrganizationEventRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.get_organization_event
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_organization_impacts(
        self,
        request: Optional[
            Union[event_resources.ListOrganizationImpactsRequest, dict]
        ] = None,
        *,
        parent: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> pagers.ListOrganizationImpactsAsyncPager:
        r"""Lists assets impacted by organization events under a
        given organization and location.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_list_organization_impacts():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.ListOrganizationImpactsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_organization_impacts(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.ListOrganizationImpactsRequest, dict]]):
                The request object. Requests list of projects under an
                organization affected by an event.
            parent (:class:`str`):
                Required. Parent value using the form
                ``organizations/{organization_id}/locations/{location}/organizationImpacts``.

                ``organization_id`` - ID (number) of the project that
                contains the event. To get your ``organization_id``, see
                `Getting your organization resource
                ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.services.service_health.pagers.ListOrganizationImpactsAsyncPager:
                Response to request for listing
                projects under an organization affected
                by an event.

                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.ListOrganizationImpactsRequest):
            request = event_resources.ListOrganizationImpactsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.list_organization_impacts
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListOrganizationImpactsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_organization_impact(
        self,
        request: Optional[
            Union[event_resources.GetOrganizationImpactRequest, dict]
        ] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> event_resources.OrganizationImpact:
        r"""Retrieves a resource containing information about
        impact to an asset under an organization affected by a
        service health event.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicehealth_v1

            async def sample_get_organization_impact():
                # Create a client
                client = servicehealth_v1.ServiceHealthAsyncClient()

                # Initialize request argument(s)
                request = servicehealth_v1.GetOrganizationImpactRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_organization_impact(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.servicehealth_v1.types.GetOrganizationImpactRequest, dict]]):
                The request object. Gets information about an event that
                affects a project under an organization.
            name (:class:`str`):
                Required. Name of the resource using the form
                ``organizations/{organization_id}/locations/global/organizationImpacts/{organization_impact_id}``.

                ``organization_id`` - ID (number) of the organization
                that contains the event. To get your
                ``organization_id``, see `Getting your organization
                resource
                ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
                ``organization_impact_id`` - ID of the
                `OrganizationImpact
                resource </service-health/docs/reference/rest/v1beta/organizations.locations.organizationImpacts#OrganizationImpact>`__.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.

        Returns:
            google.cloud.servicehealth_v1.types.OrganizationImpact:
                Represents impact to assets at
                organizational level. It is a read-only
                view and does not allow any
                modifications.

        """
        # Create or coerce a protobuf request object.
        # - Quick check: If we got a request object, we should *not* have
        #   gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        # - Use the request object if provided (there's no risk of modifying the input as
        #   there are no flattened fields), or create one.
        if not isinstance(request, event_resources.GetOrganizationImpactRequest):
            request = event_resources.GetOrganizationImpactRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self._client._transport._wrapped_methods[
            self._client._transport.get_organization_impact
        ]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_location(
        self,
        request: Optional[locations_pb2.GetLocationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> locations_pb2.Location:
        r"""Gets information about a location.

        Args:
            request (:class:`~.location_pb2.GetLocationRequest`):
                The request object. Request message for
                `GetLocation` method.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.
        Returns:
            ~.location_pb2.Location:
                Location object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.GetLocationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self.transport._wrapped_methods[self._client._transport.get_location]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_locations(
        self,
        request: Optional[locations_pb2.ListLocationsRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
    ) -> locations_pb2.ListLocationsResponse:
        r"""Lists information about the supported locations for this service.

        Args:
            request (:class:`~.location_pb2.ListLocationsRequest`):
                The request object. Request message for
                `ListLocations` method.
            retry (google.api_core.retry_async.AsyncRetry): Designation of what errors,
                 if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
                sent along with the request as metadata. Normally, each value must be of type `str`,
                but for metadata keys ending with the suffix `-bin`, the corresponding values must
                be of type `bytes`.
        Returns:
            ~.location_pb2.ListLocationsResponse:
                Response message for ``ListLocations`` method.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = locations_pb2.ListLocationsRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = self.transport._wrapped_methods[self._client._transport.list_locations]

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Validate the universe domain.
        self._client._validate_universe_domain()

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self) -> "ServiceHealthAsyncClient":
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("ServiceHealthAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.servicehealth.v1",
    manifest={
        "EventView",
        "OrganizationEventView",
        "Event",
        "OrganizationEvent",
        "EventUpdate",
        "Location",
        "Product",
        "EventImpact",
        "OrganizationImpact",
        "Asset",
        "ListEventsRequest",
        "ListEventsResponse",
        "GetEventRequest",
        "ListOrganizationEventsRequest",
        "ListOrganizationEventsResponse",
        "GetOrganizationEventRequest",
        "ListOrganizationImpactsRequest",
        "ListOrganizationImpactsResponse",
        "GetOrganizationImpactRequest",
    },
)


class EventView(proto.Enum):
    r"""The event fields to include in ListEvents API response. This
    enum lists all possible event views.

    Values:
        EVENT_VIEW_UNSPECIFIED (0):
            Unspecified event view. Default to ``EVENT_VIEW_BASIC``.
        EVENT_VIEW_BASIC (1):
            Includes all fields except ``updates``. This view is the
            default for ListEvents API.
        EVENT_VIEW_FULL (2):
            Includes all event fields.
    """
    EVENT_VIEW_UNSPECIFIED = 0
    EVENT_VIEW_BASIC = 1
    EVENT_VIEW_FULL = 2


class OrganizationEventView(proto.Enum):
    r"""The organization event fields to include in
    ListOrganizationEvents API response. This enum lists all
    possible organization event views.

    Values:
        ORGANIZATION_EVENT_VIEW_UNSPECIFIED (0):
            Unspecified event view. Default to
            ``ORGANIZATION_EVENT_VIEW_BASIC``.
        ORGANIZATION_EVENT_VIEW_BASIC (1):
            Includes all organization event fields except ``updates``.
            This view is the default for ListOrganizationEvents API.
        ORGANIZATION_EVENT_VIEW_FULL (2):
            Includes all organization event fields.
    """
    ORGANIZATION_EVENT_VIEW_UNSPECIFIED = 0
    ORGANIZATION_EVENT_VIEW_BASIC = 1
    ORGANIZATION_EVENT_VIEW_FULL = 2


class Event(proto.Message):
    r"""Represents service health events that may affect Google Cloud
    products. Event resource is a read-only view and does not allow
    any modifications. All fields are output only.

    Attributes:
        name (str):
            Output only. Identifier. Name of the event. Unique name of
            the event in this scope including project and location using
            the form
            ``projects/{project_id}/locations/{location}/events/{event_id}``.
        title (str):
            Output only. Brief description for the event.
        description (str):
            Output only. Free-form, human-readable
            description.
        category (google.cloud.servicehealth_v1.types.Event.EventCategory):
            Output only. The category of the event.
        detailed_category (google.cloud.servicehealth_v1.types.Event.DetailedCategory):
            Output only. The detailed category of the
            event.
        state (google.cloud.servicehealth_v1.types.Event.State):
            Output only. The current state of the event.
        detailed_state (google.cloud.servicehealth_v1.types.Event.DetailedState):
            Output only. The current detailed state of
            the incident.
        event_impacts (MutableSequence[google.cloud.servicehealth_v1.types.EventImpact]):
            Google Cloud products and locations impacted
            by the event.
        relevance (google.cloud.servicehealth_v1.types.Event.Relevance):
            Output only. Communicates why a given event
            is deemed relevant in the context of a given
            project.
        updates (MutableSequence[google.cloud.servicehealth_v1.types.EventUpdate]):
            Output only. Event updates are correspondence
            from Google.
        parent_event (str):
            Output only. When ``detailed_state``\ =\ ``MERGED``,
            ``parent_event`` contains the name of the parent event. All
            further updates will be published to the parent event.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the event was last
            modified.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The start time of the event, if
            applicable.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The end time of the event, if
            applicable.
        next_update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the next update
            can be expected.
    """

    class EventCategory(proto.Enum):
        r"""The category of the event. This enum lists all possible
        categories of event.

        Values:
            EVENT_CATEGORY_UNSPECIFIED (0):
                Unspecified category.
            INCIDENT (2):
                Event category for service outage or
                degradation.
        """
        EVENT_CATEGORY_UNSPECIFIED = 0
        INCIDENT = 2

    class DetailedCategory(proto.Enum):
        r"""The detailed category of an event. Contains all possible
        states for all event categories.

        Values:
            DETAILED_CATEGORY_UNSPECIFIED (0):
                Unspecified detailed category.
            CONFIRMED_INCIDENT (1):
                Indicates an event with category INCIDENT has
                a confirmed impact to at least one Google Cloud
                product.
            EMERGING_INCIDENT (2):
                Indicates an event with category INCIDENT is
                under investigation to determine if it has a
                confirmed impact on any Google Cloud products.
        """
        DETAILED_CATEGORY_UNSPECIFIED = 0
        CONFIRMED_INCIDENT = 1
        EMERGING_INCIDENT = 2

    class State(proto.Enum):
        r"""The state of the event. This enum lists all possible states
        of event.

        Values:
            STATE_UNSPECIFIED (0):
                Unspecified state.
            ACTIVE (1):
                Event is actively affecting a Google Cloud
                product and will continue to receive updates.
            CLOSED (2):
                Event is no longer affecting the Google Cloud
                product or has been merged with another event.
        """
        STATE_UNSPECIFIED = 0
        ACTIVE = 1
        CLOSED = 2

    class DetailedState(proto.Enum):
        r"""The detailed state of the incident. This enum lists all
        possible detailed states of an incident.

        Values:
            DETAILED_STATE_UNSPECIFIED (0):
                Unspecified detail state.
            EMERGING (1):
                Google engineers are actively investigating
                the event to determine the impact.
            CONFIRMED (2):
                The incident is confirmed and impacting at
                least one Google Cloud product. Ongoing status
                updates will be provided until it is resolved.
            RESOLVED (3):
                The incident is no longer affecting any
                Google Cloud product, and there will be no
                further updates.
            MERGED (4):
                The incident was merged into a parent incident. All further
                updates will be published to the parent only. The
                ``parent_event`` field contains the name of the parent.
            AUTO_CLOSED (9):
                The incident was automatically closed because of the
                following reasons:

                -  The impact of the incident could not be confirmed.
                -  The incident was intermittent or resolved itself.

                The incident does not have a resolution because no action or
                investigation happened. If it is intermittent, the incident
                may reopen.
            FALSE_POSITIVE (10):
                Upon investigation, Google engineers
                concluded that the incident is not affecting a
                Google Cloud product. This state can change if
                the incident is reviewed again.
        """
        DETAILED_STATE_UNSPECIFIED = 0
        EMERGING = 1
        CONFIRMED = 2
        RESOLVED = 3
        MERGED = 4
        AUTO_CLOSED = 9
        FALSE_POSITIVE = 10

    class Relevance(proto.Enum):
        r"""Communicates why a given incident is deemed relevant in the
        context of a given project. This enum lists all possible
        detailed states of relevance.

        Values:
            RELEVANCE_UNSPECIFIED (0):
                Unspecified relevance.
            UNKNOWN (2):
                The relevance of the incident to the project
                is unknown.
            NOT_IMPACTED (6):
                The incident does not impact the project.
            PARTIALLY_RELATED (7):
                The incident is associated with a Google
                Cloud product your project uses, but the
                incident may not be impacting your project. For
                example, the incident may be impacting a Google
                Cloud product that your project uses, but in a
                location that your project does not use.
            RELATED (8):
                The incident has a direct connection with
                your project and impacts a Google Cloud product
                in a location your project uses.
            IMPACTED (9):
                The incident is verified to be impacting your
                project.
        """
        RELEVANCE_UNSPECIFIED = 0
        UNKNOWN = 2
        NOT_IMPACTED = 6
        PARTIALLY_RELATED = 7
        RELATED = 8
        IMPACTED = 9

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    title: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    category: EventCategory = proto.Field(
        proto.ENUM,
        number=4,
        enum=EventCategory,
    )
    detailed_category: DetailedCategory = proto.Field(
        proto.ENUM,
        number=21,
        enum=DetailedCategory,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=5,
        enum=State,
    )
    detailed_state: DetailedState = proto.Field(
        proto.ENUM,
        number=19,
        enum=DetailedState,
    )
    event_impacts: MutableSequence["EventImpact"] = proto.RepeatedField(
        proto.MESSAGE,
        number=20,
        message="EventImpact",
    )
    relevance: Relevance = proto.Field(
        proto.ENUM,
        number=8,
        enum=Relevance,
    )
    updates: MutableSequence["EventUpdate"] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message="EventUpdate",
    )
    parent_event: str = proto.Field(
        proto.STRING,
        number=10,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=12,
        message=timestamp_pb2.Timestamp,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=13,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=14,
        message=timestamp_pb2.Timestamp,
    )
    next_update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=15,
        message=timestamp_pb2.Timestamp,
    )


class OrganizationEvent(proto.Message):
    r"""Represents service health events that may affect Google Cloud
    products used across the organization. It is a read-only view
    and does not allow any modifications.

    Attributes:
        name (str):
            Output only. Identifier. Name of the event. Unique name of
            the event in this scope including organization ID and
            location using the form
            ``organizations/{organization_id}/locations/{location}/organizationEvents/{event_id}``.

            ``organization_id`` - see `Getting your organization
            resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
            ``location`` - The location to get the service health events
            from. ``event_id`` - Organization event ID to retrieve.
        title (str):
            Output only. Brief description for the event.
        description (str):
            Output only. Free-form, human-readable
            description.
        category (google.cloud.servicehealth_v1.types.OrganizationEvent.EventCategory):
            Output only. The category of the event.
        detailed_category (google.cloud.servicehealth_v1.types.OrganizationEvent.DetailedCategory):
            Output only. The detailed category of the
            event.
        state (google.cloud.servicehealth_v1.types.OrganizationEvent.State):
            Output only. The current state of the event.
        detailed_state (google.cloud.servicehealth_v1.types.OrganizationEvent.DetailedState):
            Output only. The current detailed state of
            the incident.
        event_impacts (MutableSequence[google.cloud.servicehealth_v1.types.EventImpact]):
            Output only. Represents the Google Cloud
            products and locations impacted by the event.
        updates (MutableSequence[google.cloud.servicehealth_v1.types.EventUpdate]):
            Output only. Incident-only field. Event
            updates are correspondence from Google.
        parent_event (str):
            Output only. When ``detailed_state``\ =\ ``MERGED``,
            ``parent_event`` contains the name of the parent event. All
            further updates will be published to the parent event.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the update was posted.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The start time of the event, if
            applicable.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The end time of the event, if
            applicable.
        next_update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Incident-only field. The time
            when the next update can be expected.
    """

    class EventCategory(proto.Enum):
        r"""The category of the event. This enum lists all possible
        categories of event.

        Values:
            EVENT_CATEGORY_UNSPECIFIED (0):
                Unspecified category.
            INCIDENT (2):
                Event category for service outage or
                degradation.
        """
        EVENT_CATEGORY_UNSPECIFIED = 0
        INCIDENT = 2

    class DetailedCategory(proto.Enum):
        r"""The detailed category of an event. Contains all possible
        states for all event categories.

        Values:
            DETAILED_CATEGORY_UNSPECIFIED (0):
                Unspecified detailed category.
            CONFIRMED_INCIDENT (1):
                Indicates an event with category INCIDENT has
                a confirmed impact to at least one Google Cloud
                product.
            EMERGING_INCIDENT (2):
                Indicates an event with category INCIDENT is
                under investigation to determine if it has a
                confirmed impact on any Google Cloud products.
        """
        DETAILED_CATEGORY_UNSPECIFIED = 0
        CONFIRMED_INCIDENT = 1
        EMERGING_INCIDENT = 2

    class State(proto.Enum):
        r"""The state of the organization event. This enum lists all
        possible states of event.

        Values:
            STATE_UNSPECIFIED (0):
                Unspecified state.
            ACTIVE (1):
                Event is actively affecting a Google Cloud
                product and will continue to receive updates.
            CLOSED (2):
                Event is no longer affecting the Google Cloud
                product or has been merged with another event.
        """
        STATE_UNSPECIFIED = 0
        ACTIVE = 1
        CLOSED = 2

    class DetailedState(proto.Enum):
        r"""The detailed state of the incident. This enum lists all
        possible detailed states of an incident.

        Values:
            DETAILED_STATE_UNSPECIFIED (0):
                Unspecified detail state.
            EMERGING (1):
                Google engineers are actively investigating
                the incident to determine the impact.
            CONFIRMED (2):
                The incident is confirmed and impacting at
                least one Google Cloud product. Ongoing status
                updates will be provided until it is resolved.
            RESOLVED (3):
                The incident is no longer affecting any
                Google Cloud product, and there will be no
                further updates.
            MERGED (4):
                The incident was merged into a parent event. All further
                updates will be published to the parent only. The
                ``parent_event`` contains the name of the parent.
            AUTO_CLOSED (9):
                The incident was automatically closed because of the
                following reasons:

                -  The impact of the incident could not be confirmed.
                -  The incident was intermittent or resolved itself.

                The incident does not have a resolution because no action or
                investigation happened. If it is intermittent, the incident
                may reopen.
            FALSE_POSITIVE (10):
                Upon investigation, Google engineers
                concluded that the incident is not affecting a
                Google Cloud product. This state can change if
                the incident is reviewed again.
        """
        DETAILED_STATE_UNSPECIFIED = 0
        EMERGING = 1
        CONFIRMED = 2
        RESOLVED = 3
        MERGED = 4
        AUTO_CLOSED = 9
        FALSE_POSITIVE = 10

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    title: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    category: EventCategory = proto.Field(
        proto.ENUM,
        number=4,
        enum=EventCategory,
    )
    detailed_category: DetailedCategory = proto.Field(
        proto.ENUM,
        number=17,
        enum=DetailedCategory,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=5,
        enum=State,
    )
    detailed_state: DetailedState = proto.Field(
        proto.ENUM,
        number=16,
        enum=DetailedState,
    )
    event_impacts: MutableSequence["EventImpact"] = proto.RepeatedField(
        proto.MESSAGE,
        number=15,
        message="EventImpact",
    )
    updates: MutableSequence["EventUpdate"] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message="EventUpdate",
    )
    parent_event: str = proto.Field(
        proto.STRING,
        number=9,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=11,
        message=timestamp_pb2.Timestamp,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=12,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=13,
        message=timestamp_pb2.Timestamp,
    )
    next_update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=14,
        message=timestamp_pb2.Timestamp,
    )


class EventUpdate(proto.Message):
    r"""Records an update made to the event.

    Attributes:
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the update was posted.
        title (str):
            Output only. Brief title for the event.
        description (str):
            Output only. Free-form, human-readable
            description.
        symptom (str):
            Output only. Symptoms of the event, if
            available.
        workaround (str):
            Output only. Workaround steps to remediate
            the event impact, if available.
    """

    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    title: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    symptom: str = proto.Field(
        proto.STRING,
        number=4,
    )
    workaround: str = proto.Field(
        proto.STRING,
        number=5,
    )


class Location(proto.Message):
    r"""Represents the locations impacted by the event.

    Attributes:
        location_name (str):
            Location impacted by the event. Example: ``"us-central1"``
    """

    location_name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class Product(proto.Message):
    r"""Represents the Google Cloud product impacted by the event.

    Attributes:
        product_name (str):
            Google Cloud product impacted by the event. Example:
            ``"Google Cloud SQL"``
        id (str):
            Unique identifier for the product.
    """

    product_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class EventImpact(proto.Message):
    r"""Represents the Google Cloud products and locations impacted
    by the event.

    Attributes:
        product (google.cloud.servicehealth_v1.types.Product):
            Google Cloud product impacted by the event.
        location (google.cloud.servicehealth_v1.types.Location):
            Location impacted by the event.
    """

    product: "Product" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Product",
    )
    location: "Location" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Location",
    )


class OrganizationImpact(proto.Message):
    r"""Represents impact to assets at organizational level. It is a
    read-only view and does not allow any modifications.

    Attributes:
        name (str):
            Output only. Identifier. Unique name of the organization
            impact in this scope including organization and location
            using the form
            ``organizations/{organization_id}/locations/{location}/organizationImpacts/{organization_impact_id}``.

            ``organization_id`` - ID (number) of the organization that
            contains the event. To get your ``organization_id``, see
            `Getting your organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
            ``organization_impact_id`` - ID of the `OrganizationImpact
            resource </service-health/docs/reference/rest/v1beta/organizations.locations.organizationImpacts#OrganizationImpact>`__.
        events (MutableSequence[str]):
            Output only. A list of event names impacting
            the asset.
        asset (google.cloud.servicehealth_v1.types.Asset):
            Output only. Google Cloud asset possibly
            impacted by the specified events.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the affected
            project was last modified.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    events: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    asset: "Asset" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Asset",
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )


class Asset(proto.Message):
    r"""Represents the asset impacted by the events.

    Attributes:
        asset_name (str):
            Output only. Full name of the resource as defined in
            `Resource
            Names <https://cloud.google.com/apis/design/resource_names#full_resource_name>`__.
        asset_type (str):
            Output only. Type of the asset. Example:
            ``"cloudresourcemanager.googleapis.com/Project"``
    """

    asset_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    asset_type: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListEventsRequest(proto.Message):
    r"""Requests list of events.

    Attributes:
        parent (str):
            Required. Parent value using the form
            ``projects/{project_id}/locations/{location}/events``.

            ``project_id`` - ID of the project for which to list service
            health events. ``location`` - The location to get the
            service health events from. To retrieve service health
            events of category = INCIDENT, use ``location`` =
            ``global``.
        page_size (int):
            Optional. The maximum number of events that should be
            returned. Acceptable values are 1 to 100, inclusive. (The
            default value is 10.) If more results are available, the
            service returns a next_page_token that you can use to get
            the next page of results in subsequent list requests. The
            service may return fewer events than the requested
            page_size.
        page_token (str):
            Optional. A token identifying a page of results the server
            should return. Provide Page token returned by a previous
            ``ListEvents`` call to retrieve the next page of results.
            When paginating, all other parameters provided to
            ``ListEvents`` must match the call that provided the page
            token.
        filter (str):
            Optional. A filter expression that filters resources listed
            in the response. The expression takes the following forms:

            -  field=value for ``category`` and ``state``\
            -  field <, >, <=, or >= value for ``update_time`` Examples:
               ``category=INCIDENT``,
               ``update_time>="2000-01-01T11:30:00-04:00"``,
               ``event_impacts.product.product_name:"Eventarc"``

            .. raw:: html

                <br>

            Multiple filter queries are separated by spaces. Example:
            ``category=INCIDENT state=ACTIVE``.

            By default, each expression is an AND expression. However,
            you can include AND and OR expressions explicitly.

            Filter is supported for the following fields: ``category``,
            ``state``, ``update_time``,
            ``event_impacts.product.product_name``
        view (google.cloud.servicehealth_v1.types.EventView):
            Optional. Event fields to include in
            response.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    view: "EventView" = proto.Field(
        proto.ENUM,
        number=6,
        enum="EventView",
    )


class ListEventsResponse(proto.Message):
    r"""Response to request for listing events.

    Attributes:
        events (MutableSequence[google.cloud.servicehealth_v1.types.Event]):
            Output only. List of events.
        next_page_token (str):
            Output only. The continuation token, used to page through
            large result sets. Provide this value in a subsequent
            request as page_token to retrieve the next page.

            If this field is not present, there are no subsequent
            results.
        unreachable (MutableSequence[str]):
            Output only. Locations that could not be
            reached.
    """

    @property
    def raw_page(self):
        return self

    events: MutableSequence["Event"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Event",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class GetEventRequest(proto.Message):
    r"""Gets information about a specific event.

    Attributes:
        name (str):
            Required. Unique name of the event in this scope including
            project and location using the form
            ``projects/{project_id}/locations/{location}/events/{event_id}``.

            ``project_id`` - Project ID of the project that contains the
            event. ``location`` - The location to get the service health
            events from. ``event_id`` - Event ID to retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListOrganizationEventsRequest(proto.Message):
    r"""Requests list of events that affect an organization.

    Attributes:
        parent (str):
            Required. Parent value using the form
            ``organizations/{organization_id}/locations/{location}/organizationEvents``.

            ``organization_id`` - ID (number) of the project that
            contains the event. To get your ``organization_id``, see
            `Getting your organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
            ``location`` - The location to get the service health events
            from. To retrieve service health events of category =
            INCIDENT, use ``location`` = ``global``.
        page_size (int):
            Optional. The maximum number of events that should be
            returned. Acceptable values are ``1`` to ``100``, inclusive.
            (The default value is ``10``.) If more results are
            available, the service returns a ``next_page_token`` that
            you can use to get the next page of results in subsequent
            list requests. The service may return fewer events than the
            requested ``page_size``.
        page_token (str):
            Optional. A token identifying a page of results the server
            should return.

            Provide Page token returned by a previous
            ``ListOrganizationEvents`` call to retrieve the next page of
            results.

            When paginating, all other parameters provided to
            ``ListOrganizationEvents`` must match the call that provided
            the page token.
        filter (str):
            Optional. A filter expression that filters resources listed
            in the response. The expression takes the following forms:

            -  field=value for ``category`` and ``state``
            -  field <, >, <=, or >= value for ``update_time``

            Examples: ``category=INCIDENT``,
            ``update_time>="2000-01-01T11:30:00-04:00"``

            Multiple filter queries are space-separated. Example:
            ``category=INCIDENT state=ACTIVE``.

            By default, each expression is an AND expression. However,
            you can include AND and OR expressions explicitly.

            Filter is supported for the following fields: ``category``,
            ``state``, ``update_time``
        view (google.cloud.servicehealth_v1.types.OrganizationEventView):
            Optional. OrganizationEvent fields to include
            in response.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    view: "OrganizationEventView" = proto.Field(
        proto.ENUM,
        number=6,
        enum="OrganizationEventView",
    )


class ListOrganizationEventsResponse(proto.Message):
    r"""Response to request for listing organization events.

    Attributes:
        organization_events (MutableSequence[google.cloud.servicehealth_v1.types.OrganizationEvent]):
            Output only. List of organization events
            affecting an organization.
        next_page_token (str):
            Output only. The continuation token, used to page through
            large result sets. Provide this value in a subsequent
            request as ``page_token`` to retrieve the next page.

            If this field is not present, there are no subsequent
            results.
        unreachable (MutableSequence[str]):
            Output only. Locations that could not be
            reached.
    """

    @property
    def raw_page(self):
        return self

    organization_events: MutableSequence["OrganizationEvent"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="OrganizationEvent",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class GetOrganizationEventRequest(proto.Message):
    r"""Gets information about a specific event affecting an
    organization.

    Attributes:
        name (str):
            Required. Unique name of the event in this scope including
            organization and event ID using the form
            ``organizations/{organization_id}/locations/locations/global/organizationEvents/{event_id}``.

            ``organization_id`` - ID (number) of the project that
            contains the event. To get your ``organization_id``, see
            `Getting your organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
            ``event_id`` - Organization event ID to retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListOrganizationImpactsRequest(proto.Message):
    r"""Requests list of projects under an organization affected by
    an event.

    Attributes:
        parent (str):
            Required. Parent value using the form
            ``organizations/{organization_id}/locations/{location}/organizationImpacts``.

            ``organization_id`` - ID (number) of the project that
            contains the event. To get your ``organization_id``, see
            `Getting your organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
        page_size (int):
            Optional. The maximum number of events that should be
            returned. Acceptable values are ``1`` to ``100``, inclusive.
            The default value is ``10``.

            If more results are available, the service returns a
            ``next_page_token`` that can be used to get the next page of
            results in subsequent list requests. The service may return
            fewer
            `impacts </service-health/docs/reference/rest/v1beta/organizations.locations.organizationImpacts#OrganizationImpact>`__
            than the requested ``page_size``.
        page_token (str):
            Optional. A token identifying a page of results the server
            should return.

            Provide ``page_token`` returned by a previous
            ``ListOrganizationImpacts`` call to retrieve the next page
            of results.

            When paginating, all other parameters provided to
            ``ListOrganizationImpacts`` must match the call that
            provided the page token.
        filter (str):
            Optional. A filter expression that filters resources listed
            in the response. The expression is in the form of
            ``field:value`` for checking if a repeated field contains a
            value.

            Example:
            ``events:organizations%2F{organization_id}%2Flocations%2Fglobal%2ForganizationEvents%2Fevent-id``

            To get your ``{organization_id}``, see `Getting your
            organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.

            Multiple filter queries are separated by spaces.

            By default, each expression is an AND expression. However,
            you can include AND and OR expressions explicitly. Filter is
            supported for the following fields: ``events``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListOrganizationImpactsResponse(proto.Message):
    r"""Response to request for listing projects under an
    organization affected by an event.

    Attributes:
        organization_impacts (MutableSequence[google.cloud.servicehealth_v1.types.OrganizationImpact]):
            Output only. List of
            `impacts </service-health/docs/reference/rest/v1beta/organizations.locations.organizationImpacts#OrganizationImpact>`__
            for an organization affected by service health events.
        next_page_token (str):
            Output only. The continuation token, used to page through
            large result sets. Provide this value in a subsequent
            request as ``page_token`` to retrieve the next page.

            If this field is not present, there are no subsequent
            results.
        unreachable (MutableSequence[str]):
            Output only. Locations that could not be
            reached.
    """

    @property
    def raw_page(self):
        return self

    organization_impacts: MutableSequence["OrganizationImpact"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="OrganizationImpact",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class GetOrganizationImpactRequest(proto.Message):
    r"""Gets information about an event that affects a project under
    an organization.

    Attributes:
        name (str):
            Required. Name of the resource using the form
            ``organizations/{organization_id}/locations/global/organizationImpacts/{organization_impact_id}``.

            ``organization_id`` - ID (number) of the organization that
            contains the event. To get your ``organization_id``, see
            `Getting your organization resource
            ID <https://cloud.google.com/resource-manager/docs/creating-managing-organization#retrieving_your_organization_id>`__.
            ``organization_impact_id`` - ID of the `OrganizationImpact
            resource </service-health/docs/reference/rest/v1beta/organizations.locations.organizationImpacts#OrganizationImpact>`__.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.servicehealth_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.service_health import ServiceHealthAsyncClient, ServiceHealthClient
from .types.event_resources import (
    Asset,
    Event,
    EventImpact,
    EventUpdate,
    EventView,
    GetEventRequest,
    GetOrganizationEventRequest,
    GetOrganizationImpactRequest,
    ListEventsRequest,
    ListEventsResponse,
    ListOrganizationEventsRequest,
    ListOrganizationEventsResponse,
    ListOrganizationImpactsRequest,
    ListOrganizationImpactsResponse,
    Location,
    OrganizationEvent,
    OrganizationEventView,
    OrganizationImpact,
    Product,
)

__all__ = (
    "ServiceHealthAsyncClient",
    "Asset",
    "Event",
    "EventImpact",
    "EventUpdate",
    "EventView",
    "GetEventRequest",
    "GetOrganizationEventRequest",
    "GetOrganizationImpactRequest",
    "ListEventsRequest",
    "ListEventsResponse",
    "ListOrganizationEventsRequest",
    "ListOrganizationEventsResponse",
    "ListOrganizationImpactsRequest",
    "ListOrganizationImpactsResponse",
    "Location",
    "OrganizationEvent",
    "OrganizationEventView",
    "OrganizationImpact",
    "Product",
    "ServiceHealthClient",
)
